package com.mdd.admin.service.impl;

import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.mdd.admin.service.IArtCateService;
import com.mdd.admin.validate.article.ArtCateCreateValidate;
import com.mdd.admin.validate.article.ArtCateSearchValidate;
import com.mdd.admin.validate.article.ArtCateUpdateValidate;
import com.mdd.admin.validate.commons.PageValidate;
import com.mdd.admin.vo.article.ArticleCateVo;
import com.mdd.common.core.PageResult;
import com.mdd.common.entity.article.Article;
import com.mdd.common.entity.article.ArticleCategory;
import com.mdd.common.mapper.article.ArticleCategoryMapper;
import com.mdd.common.mapper.article.ArticleMapper;
import com.mdd.common.util.TimeUtils;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.List;
import javax.annotation.Resource;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.util.Assert;

@Service
public class ArtCateServiceImpl implements IArtCateService {
   @Resource
   ArticleCategoryMapper articleCategoryMapper;
   @Resource
   ArticleMapper articleMapper;

   public List<ArticleCateVo> all() {
      QueryWrapper<ArticleCategory> queryWrapper = new QueryWrapper();
      ((QueryWrapper)queryWrapper.select(new String[]{"id", "name", "sort", "is_show", "create_time", "update_time"}).eq("is_delete", 0)).orderByDesc(Arrays.asList("sort", "id"));
      List<ArticleCategory> lists = this.articleCategoryMapper.selectList(queryWrapper);
      List<ArticleCateVo> vos = new ArrayList();
      Iterator var4 = lists.iterator();

      while(var4.hasNext()) {
         ArticleCategory category = (ArticleCategory)var4.next();
         ArticleCateVo vo = new ArticleCateVo();
         BeanUtils.copyProperties(category, vo);
         vo.setCreateTime(TimeUtils.timestampToDate(vo.getCreateTime()));
         vo.setUpdateTime(TimeUtils.timestampToDate(vo.getUpdateTime()));
         vos.add(vo);
      }

      return vos;
   }

   public PageResult<ArticleCateVo> list(PageValidate pageValidate, ArtCateSearchValidate searchValidate) {
      Integer pageNo = pageValidate.getPageNo();
      Integer pageSize = pageValidate.getPageSize();
      QueryWrapper<ArticleCategory> queryWrapper = new QueryWrapper();
      ((QueryWrapper)queryWrapper.select(new String[]{"id", "name", "sort", "is_show", "create_time", "update_time"}).eq("is_delete", 0)).orderByDesc(Arrays.asList("sort", "id"));
      this.articleCategoryMapper.setSearch(queryWrapper, searchValidate, new String[]{"like:name:str", "=:isShow@is_show:int"});
      IPage<ArticleCategory> iPage = this.articleCategoryMapper.selectPage(new Page((long)pageNo, (long)pageSize), queryWrapper);
      List<ArticleCateVo> list = new ArrayList();
      Iterator var8 = iPage.getRecords().iterator();

      while(var8.hasNext()) {
         ArticleCategory category = (ArticleCategory)var8.next();
         ArticleCateVo vo = new ArticleCateVo();
         BeanUtils.copyProperties(category, vo);
         Long number = this.articleMapper.selectCount((Wrapper)((QueryWrapper)(new QueryWrapper()).eq("cid", category.getId())).eq("is_delete", 0));
         vo.setNumber(number);
         vo.setCreateTime(TimeUtils.timestampToDate(vo.getCreateTime()));
         vo.setUpdateTime(TimeUtils.timestampToDate(vo.getUpdateTime()));
         list.add(vo);
      }

      return PageResult.iPageHandle(iPage.getTotal(), iPage.getCurrent(), iPage.getSize(), list);
   }

   public ArticleCateVo detail(Integer id) {
      ArticleCategory model = (ArticleCategory)this.articleCategoryMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).select(ArticleCategory.class, (info) -> {
         return !info.getColumn().equals("is_delete") && !info.getColumn().equals("delete_time");
      }).eq("id", id)).eq("is_delete", 0));
      Assert.notNull(model, "分类不存在");
      ArticleCateVo vo = new ArticleCateVo();
      BeanUtils.copyProperties(model, vo);
      vo.setCreateTime(TimeUtils.timestampToDate(model.getCreateTime()));
      vo.setUpdateTime(TimeUtils.timestampToDate(model.getUpdateTime()));
      return vo;
   }

   public void add(ArtCateCreateValidate createValidate) {
      ArticleCategory model = new ArticleCategory();
      model.setName(createValidate.getName());
      model.setSort(createValidate.getSort());
      model.setIsShow(model.getIsShow());
      model.setCreateTime(TimeUtils.timestamp());
      model.setUpdateTime(TimeUtils.timestamp());
      this.articleCategoryMapper.insert(model);
   }

   public void edit(ArtCateUpdateValidate updateValidate) {
      ArticleCategory model = (ArticleCategory)this.articleCategoryMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).select(ArticleCategory.class, (info) -> {
         return !info.getColumn().equals("is_delete") && !info.getColumn().equals("delete_time");
      }).eq("id", updateValidate.getId())).eq("is_delete", 0));
      Assert.notNull(model, "分类不存在");
      model.setName(updateValidate.getName());
      model.setSort(updateValidate.getSort());
      model.setIsShow(updateValidate.getIsShow());
      model.setUpdateTime(TimeUtils.timestamp());
      this.articleCategoryMapper.updateById(model);
   }

   public void del(Integer id) {
      ArticleCategory model = (ArticleCategory)this.articleCategoryMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).select(new String[]{"id,is_show"}).eq("id", id)).eq("is_delete", 0));
      Assert.notNull(model, "分类不存在");
      Article article = (Article)this.articleMapper.selectOne((Wrapper)((QueryWrapper)((QueryWrapper)(new QueryWrapper()).eq("cid", id)).eq("is_delete", 0)).last("limit 1"));
      Assert.isNull(article, "当前分类已被文章使用,请先移除!");
      model.setIsDelete(1);
      model.setDeleteTime(TimeUtils.timestamp());
      this.articleCategoryMapper.updateById(model);
   }

   public void change(Integer id) {
      ArticleCategory model = (ArticleCategory)this.articleCategoryMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).select(new String[]{"id,is_show"}).eq("id", id)).eq("is_delete", 0));
      Assert.notNull(model, "分类不存在");
      model.setIsShow(model.getIsShow() == 0 ? 1 : 0);
      model.setUpdateTime(TimeUtils.timestamp());
      this.articleCategoryMapper.updateById(model);
   }
}
